betty.extension.http_api_doc package - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.http_api_doc package

## Module contents

Integrate Betty with ReDoc.

final class betty.extension.http_api_doc.HttpApiDoc

  Bases: `Extension`, `WebpackEntryPointProvider`

  Provide user-friendly HTTP API documentation.

  classmethod assets_directory_path() → Path

    Return the path on disk where the extension’s assets are located.

    This may be anywhere in your Python package.

  classmethod depends_on() → set[PluginId]

    The extensions this one depends on, and comes after.

  classmethod plugin_description() → Localizable

    Get the human-readable long plugin description.

  classmethod plugin_id() → PluginId

    Get the plugin ID.

    IDs are unique per plugin type: - A plugin repository MUST at most have a single plugin for any ID. - Different plugin repositories MAY each have a plugin with the same ID.

  classmethod plugin_label() → Localizable

    Get the human-readable short plugin label.

  webpack_entry_point_cache_keys() → Sequence[str]

    Get the keys that make a Webpack build for this provider unique.

    Providers that can be cached regardless may `return ()`.

  classmethod webpack_entry_point_directory_path() → Path

    Get the path to the directory with the entry point assets.

    The directory must include at least a `package.json` and `main.ts`.